function x = fpcg(A, b, x0, tolerance, C )
%
% This version is for positive definite symmetric A
%
time1=clock;

% setup
[n,m]=size(b);
fA = fcirc(A);
fC = fcirc(C);
% end f setup

normb=norm(b);

% initialization
x = x0;
r = b-fmult(fA,x);
t = fmult(fC,r);  % preconditioning


iter = 0;
while  min(norm(t), norm(r))/normb > tolerance
    iter = iter + 1;
    s = fmult(fC,r);   % preconditioning
    rdotr = r'*s;
    s = fmult(fA,t);
    a = rdotr/(s'*t);
       x = x + a*t;
       r = r - a*s;
    fprintf('%4g: norm(r) = %e, norm(t)= %e\n', iter, norm(r), norm(t));
    s = fmult(fC,r);  % preconditioning
    b = r'*s/rdotr;
       t = s + b*t;
end;

fprintf('Total number of iterations = %g\n', iter);
fprintf('norm(r) = %e, norm(t) = %e\n', norm(r), norm(t)); 
time2=clock;
T = etime(time2,time1);
tm = floor(T/60);
ts = floor(T - 60*tm);
fprintf('Time elapsed = %g minute(s), %g second(s).\n', tm, ts);
















